@@ -25,7 +25,12 @@ import operator
 import sys
 import unicodedata
 import types
+import platform
 
+PY_CYTHON = platform.python_implementation() == 'CPython'
+PY_PYPY = platform.python_implementation() == 'PyPy'
+PY_JYTHON = platform.python_implementation() == 'Jython'
+PY_IRON = platform.python_implementation() == 'IronPython'
 PY3 = sys.version_info[0] == 3
 
 try:
@@ -80,7 +85,9 @@ if PY3:
         return iter(d.values())
 
     def u(s):
-        return s
+        if isinstance(s, text_type):
+            return s
+        return s.decode('utf-8', 'replace')
 
     def b(s):
         if isinstance(s, binary_type):
@@ -138,10 +145,14 @@ else:
         return d.itervalues()
 
     def u(s):
+        if isinstance(s, text_type):
+            return s
         return s.decode('utf-8')
 
     def b(s):
-        return s
+        if isinstance(s, binary_type):
+            return s
+        return s.encode('utf-8', 'replace')
 
     def nativestr(s):
         if isinstance(s, binary_type):
