@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2017 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -22,7 +22,7 @@
 import sys
 from numbers import Number
 
-from glances.compat import NoOptionError, NoSectionError, range
+from glances.compat import range
 from glances.logger import logger
 from glances.exports.glances_export import GlancesExport
 
@@ -37,12 +37,17 @@ class Export(GlancesExport):
         """Init the OpenTSDB export IF."""
         super(Export, self).__init__(config=config, args=args)
 
-        # Load the InfluxDB configuration file
-        self.host = None
-        self.port = None
+        # Mandatories configuration keys (additional to host and port)
+        # N/A
+
+        # Optionals configuration keys
         self.prefix = None
         self.tags = None
-        self.export_enable = self.load_conf()
+
+        # Load the InfluxDB configuration file
+        self.export_enable = self.load_conf('opentsdb',
+                                            mandatories=['host', 'port'],
+                                            options=['prefix', 'tags'])
         if not self.export_enable:
             sys.exit(2)
 
@@ -53,36 +58,6 @@ class Export(GlancesExport):
         # Init the OpenTSDB client
         self.client = self.init()
 
-    def load_conf(self, section="opentsdb"):
-        """Load the OpenTSDB configuration in the Glances configuration file."""
-        if self.config is None:
-            return False
-        try:
-            self.host = self.config.get_value(section, 'host')
-            self.port = self.config.get_value(section, 'port')
-        except NoSectionError:
-            logger.critical("No OpenTSDB configuration found")
-            return False
-        except NoOptionError as e:
-            logger.critical("Error in the OpenTSDB configuration (%s)" % e)
-            return False
-        else:
-            logger.debug("Load OpenTSDB from the Glances configuration file")
-
-        # Prefix is optional
-        try:
-            self.prefix = self.config.get_value(section, 'prefix')
-        except NoOptionError:
-            pass
-
-        # Tags are optional, comma separated key:value pairs.
-        try:
-            self.tags = self.config.get_value(section, 'tags')
-        except NoOptionError:
-            pass
-
-        return True
-
     def init(self):
         """Init the connection to the OpenTSDB server."""
         if not self.export_enable:
