@@ -57,7 +57,7 @@ class Export(GlancesExport):
         # Init the Statsd client
         self.client = self.init()
 
-    def init(self, prefix='glances'):
+    def init(self):
         """Init the connection to the Statsd server."""
         if not self.export_enable:
             return None
@@ -66,7 +66,7 @@ class Export(GlancesExport):
                                                                     self.port))
         return StatsClient(self.host,
                            int(self.port),
-                           prefix=prefix)
+                           prefix=self.prefix)
 
     def export(self, name, columns, points):
         """Export the stats to the Statsd server."""
@@ -76,7 +76,19 @@ class Export(GlancesExport):
             stat_name = '{}.{}'.format(name, columns[i])
             stat_value = points[i]
             try:
-                self.client.gauge(stat_name, stat_value)
+                self.client.gauge(normalize(stat_name),
+                                  stat_value)
             except Exception as e:
                 logger.error("Can not export stats to Statsd (%s)" % e)
         logger.debug("Export {} stats to Statsd".format(name))
+
+
+def normalize(name):
+    """Normalize name for the Statsd convention"""
+
+    # Name should not contain some specials chars (issue #1068)
+    ret = name.replace(':', '')
+    ret = ret.replace('%', '')
+    ret = ret.replace(' ', '_')
+
+    return ret
