@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2017 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -24,7 +24,6 @@ from datetime import datetime
 
 from glances.compat import range
 from glances.processes import glances_processes, sort_stats
-# from glances.logger import logger
 
 
 class GlancesLogs(object):
@@ -147,7 +146,7 @@ class GlancesLogs(object):
                 1,  # COUNT
                 [],  # TOP 3 PROCESS LIST
                 proc_desc,  # MONITORED PROCESSES DESC
-                'cpu_percent']  # TOP PROCESS SORTKEY
+                glances_processes.sort_key]  # TOP PROCESS SORTKEY
 
             # Add the item to the list
             self.logs_list.insert(0, item)
@@ -219,4 +218,5 @@ class GlancesLogs(object):
         self.logs_list = clean_logs_list
         return self.len()
 
+
 glances_logs = GlancesLogs()
