@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2017 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -79,6 +79,13 @@ class Plugin(GlancesPlugin):
         except Exception:
             self.nb_log_core = 0
 
+        # Get the max values (dict)
+        self.max_values = glances_processes.max_values()
+
+        # Get the maximum PID number
+        # Use to optimize space (see https://github.com/nicolargo/glances/issues/959)
+        self.pid_max = glances_processes.pid_max
+
         # Note: 'glances_processes' is already init in the processes.py script
 
     def get_key(self):
@@ -102,6 +109,10 @@ class Plugin(GlancesPlugin):
                 self.stats = glances_processes.gettree()
             else:
                 self.stats = glances_processes.getlist()
+
+            # Get the max values (dict)
+            self.max_values = glances_processes.max_values()
+
         elif self.input_method == 'snmp':
             # No SNMP grab for processes
             pass
@@ -190,7 +201,10 @@ class Plugin(GlancesPlugin):
         return child_data
 
     def get_process_curses_data(self, p, first, args):
-        """Get curses data to display for a process."""
+        """Get curses data to display for a process.
+        - p is the process to display
+        - first is a tag=True if the process is the first on the list
+        """
         ret = [self.curse_new_line()]
         # CPU
         if 'cpu_percent' in p and p['cpu_percent'] is not None and p['cpu_percent'] != '':
@@ -198,16 +212,22 @@ class Plugin(GlancesPlugin):
                 msg = '{:>6.1f}'.format(p['cpu_percent'] / float(self.nb_log_core))
             else:
                 msg = '{:>6.1f}'.format(p['cpu_percent'])
-            ret.append(self.curse_add_line(msg,
-                                           self.get_alert(p['cpu_percent'], header="cpu")))
+            alert = self.get_alert(p['cpu_percent'],
+                                   highlight_zero=False,
+                                   is_max=(p['cpu_percent'] == self.max_values['cpu_percent']),
+                                   header="cpu")
+            ret.append(self.curse_add_line(msg, alert))
         else:
             msg = '{:>6}'.format('?')
             ret.append(self.curse_add_line(msg))
         # MEM
         if 'memory_percent' in p and p['memory_percent'] is not None and p['memory_percent'] != '':
             msg = '{:>6.1f}'.format(p['memory_percent'])
-            ret.append(self.curse_add_line(msg,
-                                           self.get_alert(p['memory_percent'], header="mem")))
+            alert = self.get_alert(p['memory_percent'],
+                                   highlight_zero=False,
+                                   is_max=(p['memory_percent'] == self.max_values['memory_percent']),
+                                   header="mem")
+            ret.append(self.curse_add_line(msg, alert))
         else:
             msg = '{:>6}'.format('?')
             ret.append(self.curse_add_line(msg))
@@ -224,7 +244,7 @@ class Plugin(GlancesPlugin):
             ret.append(self.curse_add_line(msg))
             ret.append(self.curse_add_line(msg))
         # PID
-        msg = '{:>6}'.format(p['pid'])
+        msg = '{:>{width}}'.format(p['pid'], width=self.__max_pid_size() + 1)
         ret.append(self.curse_add_line(msg))
         # USER
         if 'username' in p:
@@ -267,7 +287,7 @@ class Plugin(GlancesPlugin):
             except (OverflowError, TypeError) as e:
                 # Catch OverflowError on some Amazon EC2 server
                 # See https://github.com/nicolargo/glances/issues/87
-                # Also catch TypeError on Mac OS X
+                # Also catch TypeError on macOS
                 # See: https://github.com/nicolargo/glances/issues/622
                 logger.debug("Cannot get TIME+ ({})".format(e))
                 self.tag_proc_time = False
@@ -464,7 +484,7 @@ class Plugin(GlancesPlugin):
         ret.append(self.curse_add_line(msg, optional=True))
         msg = '{:>6}'.format('RES')
         ret.append(self.curse_add_line(msg, optional=True))
-        msg = '{:>6}'.format('PID')
+        msg = '{:>{width}}'.format('PID', width=self.__max_pid_size() + 1)
         ret.append(self.curse_add_line(msg))
         msg = ' {:10}'.format('USER')
         ret.append(self.curse_add_line(msg, sort_style if process_sort_key == 'username' else 'DEFAULT'))
@@ -631,3 +651,11 @@ class Plugin(GlancesPlugin):
         return sort_stats(self.stats, sortedby,
                           tree=glances_processes.is_tree_enabled(),
                           reverse=glances_processes.sort_reverse)
+
+    def __max_pid_size(self):
+        """Return the maximum PID size in number of char"""
+        if self.pid_max is not None:
+            return len(str(self.pid_max))
+        else:
+            # By default return 5 (corresponding to 99999 PID number)
+            return 5
