@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2016 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2017 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -28,9 +28,11 @@ class GlancesStatsServer(GlancesStats):
 
     """This class stores, updates and gives stats for the server."""
 
-    def __init__(self, config=None):
+    def __init__(self,
+                 config=None,
+                 args=None):
         # Init the stats
-        super(GlancesStatsServer, self).__init__(config=config)
+        super(GlancesStatsServer, self).__init__(config=config, args=args)
 
         # Init the all_stats dict used by the server
         # all_stats is a dict of dicts filled by the server
@@ -49,20 +51,8 @@ class GlancesStatsServer(GlancesStats):
     def _set_stats(self, input_stats):
         """Set the stats to the input_stats one."""
         # Build the all_stats with the get_raw() method of the plugins
-        ret = collections.defaultdict(dict)
-        for p in self._plugins:
-            ret[p] = self._plugins[p].get_raw()
-        return ret
+        return {p: self._plugins[p].get_raw() for p in self._plugins if self._plugins[p].is_enable()}
 
     def getAll(self):
         """Return the stats as a list."""
         return self.all_stats
-
-    def getAllAsDict(self):
-        """Return the stats as a dict."""
-        # Python > 2.6
-        # return {p: self.all_stats[p] for p in self._plugins}
-        ret = {}
-        for p in self._plugins:
-            ret[p] = self.all_stats[p]
-        return ret
